==> aspose_words_cloud-20.10.1.tar.gz: lib/src/models/load_web_document_data.dart <==
/*
 * --------------------------------------------------------------------------------
 * <copyright company="Aspose" file="load_web_document_data.dart">
 *   Copyright (c) 2020 Aspose.Words for Cloud
 * </copyright>
 * <summary>
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 * 
 *  The above copyright notice and this permission notice shall be included in all
 *  copies or substantial portions of the Software.
 * 
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  SOFTWARE.
 * </summary>
 * --------------------------------------------------------------------------------
 */

library aspose_words_cloud;

import '../../aspose_words_cloud.dart';

/// Contains data for load web document.
class LoadWebDocumentData implements ModelBase {
  /// Gets or sets web document url.
  String loadingDocumentUrl;

  /// Gets or sets save options.
  SaveOptionsData saveOptions;

  @override
  void deserialize(Map<String, dynamic> json) {
    if (json.containsKey('LoadingDocumentUrl')) {
      this.loadingDocumentUrl = json['LoadingDocumentUrl'];
    } else {
      this.loadingDocumentUrl = null;
    }

    if (json.containsKey('SaveOptions')) {
      this.saveOptions = new SaveOptionsData();
      this.saveOptions.deserialize(json['SaveOptions']);
    } else {
      this.saveOptions = null;
    }
  }

  @override
  Map<String, dynamic> serialize() {
    var _result = new Map<String, dynamic>();
    if (this.loadingDocumentUrl != null) {
      _result['LoadingDocumentUrl'] = this.loadingDocumentUrl;
    }

    if (this.saveOptions != null) {
      _result['SaveOptions'] = this.saveOptions.serialize();
    }
    return _result;
  }
}

==> aspose_words_cloud-20.10.2.tar.gz: lib/src/models/load_web_document_data.dart <==
/*
 * --------------------------------------------------------------------------------
 * <copyright company="Aspose" file="load_web_document_data.dart">
 *   Copyright (c) 2020 Aspose.Words for Cloud
 * </copyright>
 * <summary>
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 * 
 *  The above copyright notice and this permission notice shall be included in all
 *  copies or substantial portions of the Software.
 * 
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  SOFTWARE.
 * </summary>
 * --------------------------------------------------------------------------------
 */

library aspose_words_cloud;

import '../../aspose_words_cloud.dart';

/// Contains data for load web document.
class LoadWebDocumentData implements ModelBase {
  /// Gets or sets web document url.
  String loadingDocumentUrl;

  /// Gets or sets save options.
  SaveOptionsData saveOptions;

  @override
  void deserialize(Map<String, dynamic> json) {
    if (json.containsKey('LoadingDocumentUrl')) {
      loadingDocumentUrl = json['LoadingDocumentUrl'];
    } else {
      loadingDocumentUrl = null;
    }

    if (json.containsKey('SaveOptions')) {
      saveOptions = SaveOptionsData();
      saveOptions.deserialize(json['SaveOptions']);
    } else {
      saveOptions = null;
    }
  }

  @override
  Map<String, dynamic> serialize() {
    var _result = <String, dynamic>{};
    if (loadingDocumentUrl != null) {
      _result['LoadingDocumentUrl'] = loadingDocumentUrl;
    }

    if (saveOptions != null) {
      _result['SaveOptions'] = saveOptions.serialize();
    }
    return _result;
  }
}
